@@ -13,7 +13,6 @@
 #    under the License.
 
 import os.path
-import socket
 import string
 import tempfile
 import time
@@ -41,7 +40,6 @@ MY_IP = '10.0.0.1'
 
 class ConnectorUtilsTestCase(base.TestCase):
 
-    @mock.patch.object(socket, 'gethostname', return_value='fakehost')
     @mock.patch.object(connector.ISCSIConnector, 'get_initiator',
                        return_value='fakeinitiator')
     @mock.patch.object(linuxfc.LinuxFibreChannel, 'get_fc_wwpns',
@@ -52,13 +50,15 @@ class ConnectorUtilsTestCase(base.TestCase):
                                              enforce_multipath,
                                              multipath_result,
                                              mock_wwnns, mock_wwpns,
-                                             mock_initiator, mock_gethostname):
+                                             mock_initiator,
+                                             host='fakehost'):
         props_actual = connector.get_connector_properties('sudo',
                                                           MY_IP,
                                                           multipath,
-                                                          enforce_multipath)
+                                                          enforce_multipath,
+                                                          host=host)
         props = {'initiator': 'fakeinitiator',
-                 'host': 'fakehost',
+                 'host': host,
                  'ip': MY_IP,
                  'multipath': multipath_result}
         self.assertEqual(props, props_actual)
@@ -88,6 +88,11 @@ class ConnectorUtilsTestCase(base.TestCase):
                           self._test_brick_get_connector_properties,
                           True, True, None)
 
+    def test_brick_connector_properties_override_hostname(self):
+        override_host = 'myhostname'
+        self._test_brick_get_connector_properties(False, False, False,
+                                                  host=override_host)
+
 
 class ConnectorTestCase(base.TestCase):
 
@@ -698,6 +703,29 @@ Setting up iSCSI targets: unused
             _get_target_portals_from_iscsiadm_output(sample_input)
         self.assertEqual(out, targets)
 
+    def test_sanitize_log_run_iscsiadm(self):
+        # Tests that the parameters to the _run_iscsiadm function
+        # are sanitized for when passwords are logged.
+        def fake_debug(*args, **kwargs):
+            self.assertIn('node.session.auth.password', args[0])
+            self.assertNotIn('scrubme', args[0])
+
+        volume = {'id': 'fake_uuid'}
+        connection_info = self.iscsi_connection(volume,
+                                                "10.0.2.15:3260",
+                                                "fake_iqn")
+
+        iscsi_properties = connection_info['data']
+        with mock.patch.object(connector.LOG, 'debug',
+                               side_effect=fake_debug) as debug_mock:
+            self.connector._iscsiadm_update(iscsi_properties,
+                                            'node.session.auth.password',
+                                            'scrubme')
+
+            # we don't care what the log message is, we just want to make sure
+            # our stub method is called which asserts the password is scrubbed
+            self.assertTrue(debug_mock.called)
+
 
 class FibreChannelConnectorTestCase(ConnectorTestCase):
     def setUp(self):
